/* merriweather-cyrillic-400-italic */
@font-face {
  font-family: 'Merriweather';
  font-style: italic;
  font-display: swap;
  font-weight: 400;
  src: url(./files/merriweather-cyrillic-400-italic.woff2) format('woff2'), url(./files/merriweather-cyrillic-400-italic.woff) format('woff');
}