/* merriweather-latin-ext-300-normal */
@font-face {
  font-family: 'Merriweather';
  font-style: normal;
  font-display: swap;
  font-weight: 300;
  src: url(./files/merriweather-latin-ext-300-normal.woff2) format('woff2'), url(./files/merriweather-latin-ext-300-normal.woff) format('woff');
}

/* merriweather-latin-ext-400-normal */
@font-face {
  font-family: 'Merriweather';
  font-style: normal;
  font-display: swap;
  font-weight: 400;
  src: url(./files/merriweather-latin-ext-400-normal.woff2) format('woff2'), url(./files/merriweather-latin-ext-400-normal.woff) format('woff');
}

/* merriweather-latin-ext-700-normal */
@font-face {
  font-family: 'Merriweather';
  font-style: normal;
  font-display: swap;
  font-weight: 700;
  src: url(./files/merriweather-latin-ext-700-normal.woff2) format('woff2'), url(./files/merriweather-latin-ext-700-normal.woff) format('woff');
}

/* merriweather-latin-ext-900-normal */
@font-face {
  font-family: 'Merriweather';
  font-style: normal;
  font-display: swap;
  font-weight: 900;
  src: url(./files/merriweather-latin-ext-900-normal.woff2) format('woff2'), url(./files/merriweather-latin-ext-900-normal.woff) format('woff');
}